@@ -15,11 +15,10 @@ from utilities.forms import (
     DynamicModelChoiceField, APISelect,
 )
 
-from netbox_storage.models import Partition, Drive
+from netbox_storage.models import Partition, Drive, Filesystem
 
 
 class PartitionForm(NetBoxModelForm):
-    """Form for creating a new Partition object."""
     drive = DynamicModelChoiceField(
         queryset=Drive.objects.all(),
         label="Drive",
@@ -28,8 +27,9 @@ class PartitionForm(NetBoxModelForm):
         ),
         help_text="The Drive of the VM e.g. Drive 1",
     )
-    device = CharField(
-        label="Device",
+    letter = CharField(
+        required=False,
+        label="Partition Letter",
         help_text="The device name e.g. /dev/sdc1",
     )
     size = FloatField(
@@ -37,9 +37,24 @@ class PartitionForm(NetBoxModelForm):
         help_text="The size of the partition e.g. 25",
         validators=[MinValueValidator(0.0)],
     )
-    type = CharField(
-        label="Type",
-        help_text="The type of the partition e.g. Linux LVM",
+    fs_type = DynamicModelChoiceField(
+        required=False,
+        queryset=Filesystem.objects.all(),
+        label="Filesystem Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
+        ),
+        help_text="The Filesystem of the Volume e.g. ext4",
+    )
+    mountpoint = CharField(
+        required=False,
+        label="Mountpoint",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
+    )
+    fs_options = CharField(
+        required=False,
+        label="FS Options",
+        help_text="The mounted point of the volume e.g. /var/lib/docker",
     )
     description = CharField(
         required=False,
@@ -47,15 +62,29 @@ class PartitionForm(NetBoxModelForm):
         help_text="Short Description e.g. Partition 1 on SSD Cluster",
     )
 
+    fieldsets = (
+        (
+            "Select drive",
+            (
+                "drive",
+            ),
+        ),
+        (
+            "Partition Details",
+            (
+                "size",
+                'letter',
+                'fs_type',
+                'description'
+            ),
+        ),
+    )
+
     class Meta:
         model = Partition
 
         fields = (
-            "drive",
-            "device",
-            "size",
-            "type",
-            "description",
+            'drive', 'size', 'fs_type', 'letter', 'description'
         )
 
 
@@ -135,9 +164,9 @@ class PartitionImportForm(NetBoxModelImportForm):
 
         fields = (
             "drive",
-            "device",
+            "letter",
             "size",
-            "type",
+            "fs_type",
             "description",
         )
 
@@ -153,7 +182,7 @@ class PartitionBulkEditForm(NetBoxModelBulkEditForm):
         ),
         help_text="The Drive of the VM e.g. Drive 1",
     )
-    device = CharField(
+    letter = CharField(
         required=False,
         label="Device",
         help_text="The device name e.g. /dev/sdc1",
@@ -164,7 +193,7 @@ class PartitionBulkEditForm(NetBoxModelBulkEditForm):
         help_text="The size of the partition e.g. 25",
         validators=[MinValueValidator(0.0)],
     )
-    type = CharField(
+    fs_type = CharField(
         required=False,
         label="Type",
         help_text="The type of the partition e.g. Linux LVM",
@@ -178,7 +207,7 @@ class PartitionBulkEditForm(NetBoxModelBulkEditForm):
     fieldsets = (
         (
             None,
-            ("drive", "device", "size", "type", "description")
+            ("drive", "letter", "size", "fs_type", "description")
         ),
     )
     nullable_fields = ["description"]
