@@ -7,6 +7,7 @@ from netbox_storage.views import (
     # Drive View
     DriveListView,
     DriveView,
+    DriveAddView,
     DriveEditView,
     DriveDeleteView,
     DriveBulkImportView,
@@ -58,7 +59,7 @@ urlpatterns = [
     # Drive urls
     #
     path("drive/", DriveListView.as_view(), name="drive_list"),
-    path("drive/add/", DriveEditView.as_view(), name="drive_add"),
+    path("drive/add/", DriveAddView.as_view(), name="drive_add"),
     path("drive/import/", DriveBulkImportView.as_view(), name="drive_import"),
     path("drive/edit/", DriveBulkEditView.as_view(), name="drive_bulk_edit"),
     path("drive/delete/", DriveBulkDeleteView.as_view(), name="drive_bulk_delete"),
